/*
 * Copyright (c) 2015, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.wso2.carbon.identity.application.common.cache;

import org.wso2.carbon.context.CarbonContext;
import org.wso2.carbon.identity.core.cache.BaseCache;

/**
 * Cache to contain randomized passwords.
 */
public class RandomPasswordContainerCache
        extends BaseCache<RandomPasswordContainerCacheKey, RandomPasswordContainerCacheEntry> {

    private static final String RANDOM_PASSWORD_CACHE_NAME = "RandomPasswordContainerCache";

    private static volatile RandomPasswordContainerCache instance;

    private RandomPasswordContainerCache() {

        super(RANDOM_PASSWORD_CACHE_NAME);
    }

    public static RandomPasswordContainerCache getInstance() {

        if (instance == null) {
            synchronized (RandomPasswordContainerCache.class) {
                if (instance == null) {
                    instance = new RandomPasswordContainerCache();
                }
            }
        }
        return instance;
    }

    public void addToCache(RandomPasswordContainerCacheKey key, RandomPasswordContainerCacheEntry entry) {

        super.addToCache(key, entry, CarbonContext.getThreadLocalCarbonContext().getTenantDomain());
    }

    public RandomPasswordContainerCacheEntry getValueFromCache(RandomPasswordContainerCacheKey key) {

        RandomPasswordContainerCacheEntry cacheEntry = super.getValueFromCache(key,
                CarbonContext.getThreadLocalCarbonContext().getTenantDomain());
        return cacheEntry;
    }

    public void clearCacheEntry(RandomPasswordContainerCacheKey key) {

        super.clearCacheEntry(key, CarbonContext.getThreadLocalCarbonContext().getTenantDomain());
    }
}
